#
# spec file for package gnome-subtitles
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-subtitles
Version:        1.7.2
Release:        1.7
Summary:        Subtitle editor for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://gnomesubtitles.org/
Source0:        https://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE gnome-subtitles-gtk-sharp-build-fix.patch mgorse@suse.com -- fix build against new gtk-sharp.
Patch0:         gnome-subtitles-gtk-sharp-build-fix.patch
BuildRequires:  enchant-devel > 2.0
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  intltool >= 0.50
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.0
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= 1.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12
BuildRequires:  pkgconfig(gtk-sharp-3.0) >= 2.99.3
BuildRequires:  pkgconfig(mono) >= 4.0
Requires:       gstreamer-plugins-base
Requires:       hicolor-icon-theme
Requires:       mono-core

%description
Gnome Subtitles is a subtitle editor for the GNOME desktop. It supports
the most common text-based subtitle formats and allows for subtitle
editing, translation and synchronization.

%lang_package

%prep
%autosetup -p1

%build
%configure \
	--enable-gtk-doc \
	%{nil}
# Disable parallel build - mono fails too often with it
make -j1

%install
%make_install
find %{buildroot}%{_libdir} -type f -name "*.la" -delete
%find_lang %{name} %{?no_lang_C}
%find_lang org.gnome.GnomeSubtitles %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_mandir}/man1/gnome-subtitles.1%{ext_man}
%{_datadir}/glib-2.0/schemas/org.gnome.GnomeSubtitles.gschema.xml
%{_datadir}/icons/hicolor/*/apps/gnome-subtitles.svg
%{_datadir}/applications/org.gnome.GnomeSubtitles.desktop
%{_datadir}/help/C/gnome-subtitles/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.GnomeSubtitles.appdata.xml

%files lang -f %{name}.lang -f org.gnome.GnomeSubtitles.lang

%changelog
* Wed Dec 15 2021 Michael Gorse <mgorse@suse.com>
- Update to version 1.7.2:
  + Fixed a crash that occured in some distros due to missing libdl
    or dlopen (boo#1191250).
  + Updated translations.
- Changes in version 1.7.1:
  + Fixed a crash that occurred when opening some media files.
* Mon Sep 27 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.7:
  * Fixed multiple issues related to audio and video playback
  * GStreamer media playback engine rewrite
  * Subtitle lines displayed on the video are now immediately
    refreshed if changed
  * Fixed an issue which didn't allow for multiple Gnome Subtitles
    instances to be running simultaneously
  * Fixed an issue which prevented the application from appearing
    translated/localized
  * Fixed an issue with Autocheck Spelling not working immediately
    when the app is opened
  * Help menu items now open correctly
  * Improved the Set Languages dialog window with information on
    how to install additional language packs
  * Fixed an issue with the side bar constantly resizing
    during playback
  * Fixed an issue where opening an audio file after a video
    would show the last frame played from the video
  * Added support for Enchant 2 (in addition to Enchant 1
    which is still supported)
  * Optimization to only save the window state when closing
    the application
  * AppData and Desktop files have been updated
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Apr  5 2020 Michael Gorse <mgorse@suse.com>
- Update to version 1.6:
  +  Fixed a crash when opening translation files.
  +  Show all media files (video and audio) by default in the
    Video File Open dialog.
  +  UTF-8 files are now saved with a BOM (byte order mark) by
    default (as happened until version 1.4.2). An option has been
    added to allow saving files in this encoding without a BOM.
  + Bug fixes:
  - Video File Open: show all media files by default (#136).
  - Crash when opening translation file (#138).
  - Allow to save UTF-8 files with or without a BOM (#140).
  + Updated translations.
  + Changes in version 1.5:
  +  Fixed a crash that occurred when using Video > Loop Selection.
  +  Subtitle Split was improved to split every line (previously,
    it was divided into 2 halves) and only split subtitles
    containing multiple lines.
  +  Fixed a bug where subtitle lines with ampersand (&) and other
    characters were not being displayed on video playback.
  +  Stopped "source ID not found" messages from being written in
    the console/logs.
  +  Subtitles displayed on video playback are now properly cleared
    after closing a subtitle file.
  +  The video image is also now properly cleared after closing the
    video.
  +  Fixed a couple of bugs that prevented the application from
    appearing fully translated.
  +  Fixed a bug in the Preferences Dialog where values like Gap
    Between Subtitles were not being saved when changed via the
    keyboard.
  +  The application now better integrates with some desktop
    environments by setting its ApplicationID.
  + Bug fixes:
  - Crash in Video > Loop Selection (#124).
  - Split improvements: split all lines (previously were split
    into 2 halves) and only split subtitles with multiple lines
    (#2).
  - Undo/Redo in commands with text and translations must
    consider if the translation was reloaded (#126).
  - Preferences Dialog: values like Gap Between Subtitles are
    not saved when set with the keyboard (#127).
  - Syslog full of "source ID not found" (#4).
  - Video not showing text with ampersand (#128).
  - Clear video subtitle on File Close (#129).
  - Video area not cleared after closing it (#130).
  - Don't show the video file chooser in the File > Translation
    Open dialog (#131).
  - File Open/Save error dialogs have wrong action set as
    default (#132).
  - Typo (occured) in translatable strings (#94).
  - UI in English, expected translated (#125).
  - Some strings are displayed untranslated (#91).
  - pt_PT translation: multiple letters in upper case when
    preceded by an underscore (#133).
  - Set ApplicationID to use .desktop file (#134).
  - App icon is incorrect in alt+tab menu (#118).
- Adjust source URI.
- Add hicolor-icon-theme to requires.
- Add gnome-subtitles-gtk-sharp-build-fix.patch: adjust for a
  post-2.99.3 gtk-sharp API change (we currently ship a git
  snapshot).
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Dec 25 2018 bjorn.lie@gmail.com
- Update to version 1.4.2:
  + Fixed a bug where the Timings Shift dialog was unable to handle
    negative shift amounts.
  + The byte order mark (BOM) is no longer inserted at the
    beginning of files saved with UTF-8 encoding.
  + Fixed a bug with the Translation Save dialog appearing after
    cancelling the Subtitle Save dialog.
  + Migrated from gnome-doc-utils to yelp-tools (GNOME Goal: Port
    To New Documentation Infrastructure).
  + Updated the website URLs
  + Bug fixes:
  - Negative time shift not work
    (glgo#GNOME/gnome-subtitles#112).
  - Don't insert the BOM (byte order mark) when saving files with
    UTF-8 encoding (glgo#GNOME/gnome-subtitles#113)
  + Updated translations.
- Replace with gnome-doc-utils-devel yelp-tools BuildRequires,
  following upstream changes.
- Switch to gitlab.gnome.org as "home" URL.
- Switch to upstream released tarball, remove all conditionals for
  service usage of git checkouts. Drop gnome-common BuildRequires.
- Add yelp-tools BuildRequires, new dependency.
- Drop update-desktop-files BuildRequires and post(un) handling of
  desktop_database_post(un) macro, no longer needed for any current
  version of openSUSE.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Own metainfo dir to fix build on old versions of openSUSE.
* Mon Oct 29 2018 dimstar@opensuse.org
- Update to version 1.4.1+12:
  + Don't write UTF-8 files with BOM.
  + Fix #112 - negative time shift not work.
  + Updating autogen.sh file for yelp-tools use.
  + Updating gitignore+NEWS files for yelp-tools use.
  + Port help to yelp-tools.
  + Default number column width is now 4 chars.
  + Fixed #3 - System freezes when using v 1.4.
  + Fix keywords in Icelandic translation.
  + Updating AppStream and Desktop files.
  + Fix Keywords in Romanian translation.
  + Fixed copy/cut buttons' sensitivity.
  + Updating dependencies.
  + Updating build configuration..
  + Unmark strings from translation that shouldn’t be translatable.
  + Minor UI changes.
  + Switched to gtksink to display gstreamer video.
  + Updating Makefiles for new GtkSpell code.
  + Updated README file dependencies and other info.
  + GtkSpell upgraded to 3.0 and code refactor.
  + Updated translations.
* Mon Jun 11 2018 luc14n0@linuxmail.org
- Update to version 1.3+142:
  + Several minor fixes.
  + Update translation.
- Replace devel packages BuildRequires with their respective
  pkgconfig modules for gstreamer, gstreamer-plugins-base,
  gtk-sharp3, gtk3 and mono: these are what configure really looks
  for.
- Update post(un) scriptlets to be ran in release versions < 1500.
- Add conditionalized gnome-common and gtk-doc BuildRequires when
  building from a git tree.
- Pass enable-gtk-doc parameter to configure to allow building of
  API docs while dropping disable-schemas-install configure
  parameter, it doesn't exist anymore.
- Conditionalize gnome-doc-utils-devel BuildRequires: this is
  required only when building from a git tree.
- Drop:
  + suse_update_desktop_file macro call: it is no longer required.
  + gconf-sharp2, gconf2-devel, glade-sharp3 and gtkspell
    BuildRequires, and glade-sharp2, gnome-sharp2 and gtkspell
    Requires: they are no longer required nor used.
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 1.3:
  + Allow to set the gap between subtitles, to be used when
    inserting or splitting subtitles.
  + Fixed character count when editing text.
  + Multiple subtitle engine fixes.
  + Switched to GStreamer 1.0.
  + Fixed Help menu items.
  + Bugs fixed: bgo#643389, bgo#671567, bgo#659524, bgo#673126,
    bgo#694818, bgo#621475.
  + Updated translations.
- Replace BuildRequires for GStreamer 1.0 port:
  + Old: gstreamer-0_10-devel, gstreamer-0_10-plugins-base-devel,
    gtk2-devel.
  + New: gstreamer-devel, gstreamer-plugins-base-devel, gtk2-devel.
- Replace gstreamer-0_10-plugins-base Requires with
  gstreamer-plugins-base.
- Disable parallel build, as there are random build failures
  observed.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 1.2:
  + Support for merging and splitting subtitle lines
  + Allow to view character counts in the subtitle list and editing
    area
  + Allow to apply a reaction delay when timing start/end on video
    playblack
  + Video slow and fast motion options
  + New shortcuts for quick timings change:
  - Increase/decrease subtitle start time: Ctrl+Plus/Minus
  - Increase/decrease subtitle end time: Alt+Plus/Minus
  - Shift subtitles: Shift+Plus/Minus
  + Automatically seek the video when subtitle times are changed,
    with an option to rewind it some milliseconds
  + Added support for the Fab Subtitler subtitle format
  + Allow to insert a new subtitle at the current video position,
    applying a reaction delay if set
  + Other changes:
  - Translation filenames are now based on the original filename
    plus language
  - Added support for buggy SubRip files that use dots instead of
    commas
  - Fixed bug with the subtitle overlay not being updated on
    times change
  - Detect when selecting a video file as the subtitle file
  - Updated preferences dialog with different structure and more
    options
  - Fixed special characters (<,>,&,etc) not being shown in the
    subtitle list
  + Bugs fixed: bgo#453469, bgo#607227, bgo#607228, bgo#607229,
    bgo#620776, bgo#621145, bgo#621943, bgo#625485, bgo#634230,
    bgo#636766, bgo#636767, bgo#638238, bgo#638484, bgo#642674,
    bgo#648461, bgo#651958
  + Updated translations.
- Drop patches:
  + gnome-subtitles-desktop-entry.patch: fixed upstream.
  + gnome-subtitles-module.patch: fixed upstream.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Wed Dec  8 2010 vuntz@opensuse.org
- Improve description.
- Change mono Requires to mono-core.
- Add mention of upstream bug numbers for the patches.
- Simplify gnome-subtitles-desktop-entry.patch: the change in the
  Categories key does nothing.
* Thu Nov 11 2010 badshah400@gmail.com
- Initial build (version 1.1)
